<?php

namespace apexl\Io\modules\formbuilder\includes;

class checkboxField extends formField
{
    public function __construct($name)
    {
        parent::__construct($name, 'input', 'checkbox');
    }

    public function setChecked(bool $checked = true): static
    {
        $this->field->checked = $checked;

        return $this;
    }
}
